@@ -86,12 +86,12 @@
       (and (not (empty-slot? 1))
 	   (deal-cards-face-up 1 (list slot)))
       (and (not (empty-slot? 0))
-	   (deal-cards-face-up 0 (list slot))
-	   (give-status-message))
+	   (deal-cards-face-up 0 (list slot)))
       #t))
 
 (define (droppable? start-slot card-list end-slot)
-  (cond ((> end-slot 9)
+  (cond ((= start-slot end-slot) #f)
+        ((> end-slot 9)
 	 (and (= (length card-list) 1)
 	      (not (empty-slot? end-slot))
 	      (not (eq? (is-red? (car card-list))
@@ -112,13 +112,17 @@
            (begin
              (move-n-cards! start-slot end-slot (reverse card-list))
              (add-to-score! (length card-list))))
-       (empty-tableau start-slot)
-       (give-status-message)))
+       (empty-tableau start-slot)))
+
+(define (do-deal-next-cards)
+  (flip-stock 0 1 1))
+
+(define (dealable?)
+  (flippable? 0 1 1))
 
 (define (button-clicked slot-id)
   (and (= slot-id 0)
-       (flip-stock 0 1 1)
-       (give-status-message)))
+       (do-deal-next-cards)))
 
 (define (move-to-foundation slot-id foundation-id)
   (cond ((= foundation-id 10)
@@ -142,6 +146,7 @@
        (add-to-score! 1)))
 
 (define (game-continuable)
+  (give-status-message)
   (get-hint))
 
 (define (game-won)
@@ -154,13 +159,6 @@
        (= (length (get-cards 8)) 13)
        (= (length (get-cards 9)) 13)))
 
-(define (dealable?)
-  (or (and (not (empty-slot? 0))
-	   (list 0 (_"Deal another round")))
-      (and (not (empty-slot? 1))
-	   (< FLIP-COUNTER 1)
-	   (list 0 (_"Move waste back to stock")))))
-
 (define (check-a-foundation slot-id foundation-id)
   (cond ((= foundation-id 10)
 	 #f)
@@ -215,7 +213,11 @@
 (define (get-hint)
   (or (check-to-foundations 1)
       (check-to-tableaus 1)
-      (dealable?)))
+      (or (and (not (empty-slot? 0))
+              (list 0 (_"Deal another round")))
+          (and (not (empty-slot? 1))
+              (< FLIP-COUNTER 1)
+              (list 0 (_"Move waste back to stock"))))))
 
 (define (get-options) 
   #f)
@@ -226,8 +228,8 @@
 (define (timeout) 
   #f)
 
-(set-features droppable-feature)
+(set-features droppable-feature dealable-feature)
 
 (set-lambda new-game button-pressed button-released button-clicked
 button-double-clicked game-continuable game-won get-hint get-options
-apply-options timeout droppable?)
+apply-options timeout droppable? dealable?)
