@@ -230,6 +230,12 @@
 
 ;; Utilities
 
+(define (flippable? stock-slot waste-slot flip-limit)
+  (or (not (empty-slot? stock-slot))
+      (and (not (empty-slot? waste-slot))
+           (or (< flip-limit 0)
+               (< FLIP-COUNTER flip-limit)))))
+
 ; deal a card from the stock-slot to the waste-slot.
 ; when the stock slot is empty than the waste slot will be flipped back
 ; onto the stock unless the flip limit has been reached.
@@ -237,7 +243,8 @@
 ; If the flip limit is negative, it is treated as infinite.
 (define (flip-stock stock-slot waste-slot flip-limit . rest)
   (if (empty-slot? stock-slot)
-      (and (or (< flip-limit 0)
+      (and (not (empty-slot? waste-slot))
+           (or (< flip-limit 0)
 	       (< FLIP-COUNTER flip-limit))
 	   (set! FLIP-COUNTER (+ 1 FLIP-COUNTER))
 	   (flip-deck stock-slot waste-slot))
@@ -322,6 +329,15 @@
 	(car cards))))
 
 ;; Utilities - need more of these:
+(define (suit-eq? card1 card2)
+  (eq? (get-suit card1) (get-suit card2)))
+
+(define (color-eq? card1 card2)
+  (eq? (get-color card1) (get-color card2)))
+
+(define (value-eq? card1 card2)
+  (eq? (get-value card1) (get-value card2)))
+
 (define (cards-eq? card1 card2)
   (and (eq? (get-value card1) (get-value card2))
        (eq? (get-suit card1) (get-suit card2))))
