@@ -34,7 +34,6 @@
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.h>
-#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #include "main.h"
@@ -284,7 +283,7 @@ key_press_cb (GtkWidget * widget, GdkEventKey * event)
 }
 
 static void
-draw_board ()
+draw_board (void)
 {
   int i, j;
 
@@ -489,17 +488,6 @@ pause_game_cb (GtkAction * action, gpointer data)
   if (paused) {
     paused = 0;
     dummy_id = g_timeout_add (500, (GSourceFunc) new_game_2_cb, NULL);
-    /*
-     * main_id = gtk_timeout_add (GAMEDELAY * properties->gamespeed,
-     * (GtkFunction) main_loop, NULL);
-     * keyboard_id = g_signal_connect (GTK_OBJECT (window),
-     * "key_press_event", G_CALLBACK (key_press_cb),
-     * NULL);
-     * add_bonus_id = gtk_timeout_add (BONUSDELAY *
-     * properties->gamespeed,
-     * (GtkFunction) add_bonus_cb,
-     * NULL);
-     */
   } else {
     if (main_id || erase_id || restart_id || dummy_id) {
       paused = 1;
@@ -1051,7 +1039,6 @@ main (int argc, char **argv)
 #endif 
 
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
-  games_sound_add_option_group (context);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
