@@ -20,13 +20,16 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <games-preimage.h>
-#include <games-find-file.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
+#include <libgames-support/games-find-file.h>
+#include <libgames-support/games-preimage.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
 
 #include <sys/types.h>
 #include <string.h>
@@ -172,9 +175,9 @@ static gboolean
 load_bubble_graphics (void)
 {
   gchar *buffer = NULL;
-  gchar *dname =
-    gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-			       GAME_NAME, FALSE, NULL);
+  const char *dname;
+
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
 
   buffer = g_build_filename (dname, "yahoo.png", NULL);
   if (!load_bubble_graphic (buffer, &yahoo_pixbuf))
@@ -206,18 +209,20 @@ gboolean
 load_game_graphics (void)
 {
   gchar *filename;
+  const char *pixmapdir;
 
   if (theme_preimage != NULL) {
     free_game_graphics ();
   }
 
-  filename = games_find_similar_file (properties_theme_name (), PIXMAPDIR);
+  pixmapdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  filename = games_find_similar_file (properties_theme_name (), pixmapdir);
 
   theme_preimage = games_preimage_new_from_file (filename, NULL);
   g_free (filename);
 
   if (theme_preimage == NULL) {
-    filename = games_find_similar_file ("robots", PIXMAPDIR);
+    filename = games_find_similar_file ("robots", pixmapdir);
     theme_preimage = games_preimage_new_from_file (filename, NULL);
     g_free (filename);
   }
