@@ -27,8 +27,8 @@
 #include "renderer.h"
 #include "blocks.h"
 
-#include <clutter-cairo/clutter-cairo.h>
-#include <libgames-support/games-clutter-embed.h>
+#include <clutter/clutter.h>
+#include <clutter-gtk/clutter-gtk.h>
 
 class Preview {
 public:
@@ -40,26 +40,30 @@ public:
 	}
 
 	void enable (bool enable);
-	void previewBlock (int bnr, int brot, int bcolor);
-	void setTheme (int id);
+	void setTheme (gint id);
+	void previewBlock (int bnr, int bcolor);
+	void regenerateRenderer ();
 
 private:
-	GtkWidget * w;
+	GtkWidget *w;
 	gint width;
 	gint height;
+	gint blocknr;
+	gint color;
+	gint themeID;
 
-	int blocknr;
-	int blockrot;
-	int blockcolor;
+	ClutterTimeline *piece_timeline;
+	ClutterAlpha *alpha;
+	ClutterBehaviour *piece_behav;
+
+	Block **blocks;
+	ClutterActor* piece;
+	Renderer* renderer;
 
 	bool enabled;
 
-	int themeID;
-	cairo_surface_t *background;
-
-	static gint configure (GtkWidget * widget, GdkEventConfigure * event,
-			       Preview * preview);
-	Block **blocks;
+	static gboolean resize(GtkWidget *widget, GtkAllocation *event,
+			       Preview *preview);
 };
 
 #endif //__preview_h__
