@@ -42,17 +42,9 @@
 #include "blocks.h"
 #include "scoreframe.h"
 #include "highscores.h"
-
-#ifdef HAVE_CLUTTER
 #include "preview.h"
 #include "renderer.h"
 #include "blockops.h"
-#else
-#include "preview-noclutter.h"
-#include "field-noclutter.h"
-#include "renderer-noclutter.h"
-#include "blockops-noclutter.h"
-#endif
 
 int LINES = 20;
 int COLUMNS = 14;
@@ -89,9 +81,6 @@ Tetris::Tetris(int cmdlLevel):
 	timeoutId(0),
 	onePause(false),
 	inPlay(false),
-#ifndef HAVE_CLUTTER
-	useTarget(false),
-#endif
 	bgimage(0),
 	setupdialog(0),
 	cmdlineLevel(cmdlLevel),
@@ -188,12 +177,7 @@ Tetris::Tetris(int cmdlLevel):
 	games_conf_add_window (GTK_WINDOW (w), KEY_SAVED_GROUP);
 
 	preview = new Preview ();
-#ifdef HAVE_CLUTTER
 	field = new BlockOps ();
-#else
-	field = new Field();
-	field->setUseTarget (false);
-#endif
 
 	initOptions ();
 
@@ -231,7 +215,7 @@ Tetris::Tetris(int cmdlLevel):
 	gtk_container_add (GTK_CONTAINER (aspect_frame), field->getWidget());
 
 	gtk_widget_set_events(w, gtk_widget_get_events(w) |
-						  GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
+			      GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 
 	GtkWidget *vb1 = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vb1), 10);
@@ -258,15 +242,7 @@ Tetris::Tetris(int cmdlLevel):
 
 	themeList = NULL;
 
-	gtk_widget_show(vbox);
-	gtk_widget_show(hb);
-	gtk_widget_show(vb1);
-	gtk_widget_show(vb2);
-	gtk_widget_show(aspect_frame);
-	gtk_widget_show(field->getWidget());
-	gtk_widget_show(preview->getWidget());
-	scoreFrame->show();
-	gtk_widget_show(w);
+	gtk_widget_show_all(w);
 
 	gtk_action_set_sensitive(pause_action, FALSE);
 	gtk_action_set_sensitive(end_game_action, FALSE);
@@ -446,10 +422,6 @@ Tetris::initOptions ()
 
 	games_sound_enable (confGetBoolean (KEY_OPTIONS_GROUP, KEY_SOUND, TRUE));
 
-#ifndef HAVE_CLUTTER
-	useTarget = confGetBoolean (KEY_OPTIONS_GROUP, KEY_USE_TARGET, FALSE);
-#endif
-
 	do_preview = confGetBoolean (KEY_OPTIONS_GROUP, KEY_DO_PREVIEW, TRUE);
 
 	if (preview) {
@@ -500,9 +472,6 @@ Tetris::setOptions ()
 
 		if (theme_preview) {
 			theme_preview->setTheme (themeno);
-#ifndef HAVE_CLUTTER
-			gtk_widget_queue_draw(theme_preview->getWidget());
-#endif
 		}
 	}
 
@@ -551,21 +520,6 @@ Tetris::setSelection(GtkWidget *widget, void *data)
 			       ThemeTable[t->themeno].id);
 }
 
-#ifndef HAVE_CLUTTER
-void
-Tetris::setTarget (GtkWidget *widget, void *data)
-{
-	Tetris *t;
-
-	t = (Tetris *)data;
-
-	t->useTarget = GTK_TOGGLE_BUTTON (widget)->active;
-
-	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_USE_TARGET,
-				t->useTarget);
-}
-#endif
-
 void
 Tetris::lineFillHeightChanged (GtkWidget *spin, gpointer data)
 {
@@ -741,12 +695,6 @@ Tetris::gameProperties(GtkAction *action, void *d)
 			    0, 0, 0);
 
 	t->useTargetToggle = gtk_check_button_new_with_mnemonic (_("Show _where the block will land"));
-#ifndef HAVE_CLUTTER
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (t->useTargetToggle),
-				      t->useTarget);
-	g_signal_connect (t->useTargetToggle, "clicked",
-			  G_CALLBACK (setTarget), d);
-#endif
  	gtk_box_pack_start (GTK_BOX (fvbox), t->useTargetToggle,
 			    0, 0, 0);
 
@@ -810,11 +758,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	t->theme_preview->setTheme (t->themeno);
 	gtk_box_pack_start(GTK_BOX(fvbox), t->theme_preview->getWidget(), TRUE, TRUE, 0);
 
-#ifndef HAVE_CLUTTER
-	t->theme_preview->previewBlock(4, 0, 0);
-#else
 	t->theme_preview->previewBlock(4, 0);
-#endif
 
 	gtk_widget_show_all (t->setupdialog);
 	gtk_action_set_sensitive(t->new_game_action, FALSE);
@@ -913,20 +857,12 @@ Tetris::timeoutHandler(void *d)
 	if (t->onePause)
 	{
 		t->onePause = false;
-#ifdef HAVE_CLUTTER
 		t->field->drawMessage();
-#else
-		t->field->redraw();
-#endif
 	}
 	else
 	{
 		bool res = t->field->moveBlockDown();
 
-#ifndef HAVE_CLUTTER
-		t->field->redraw();
-#endif
-
 		if (res)
 		{
 			t->manageFallen();
@@ -990,10 +926,6 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 		}
 	}
 
-#ifndef HAVE_CLUTTER
-	t->field->redraw();
-#endif
-
 	return res;
 }
 
@@ -1242,14 +1174,8 @@ Tetris::generate()
 {
 	if (field->generateFallingBlock())
 	{
-#ifndef HAVE_CLUTTER
-		field->putBlockInField(false);
-		preview->previewBlock(blocknr_next, rot_next, color_next);
-		gtk_widget_queue_draw(preview->getWidget());
-#else
 		field->putBlockInField(FALLING);
 		preview->previewBlock(blocknr_next, color_next);
-#endif
 		onePause = true;
 	}
 	else
@@ -1273,12 +1199,7 @@ Tetris::endOfGame()
 	color_next = -1;
 	blocknr_next = -1;
 	rot_next = -1;
-#ifndef HAVE_CLUTTER
-	preview->previewBlock(-1, -1, -1);
-	gtk_widget_queue_draw(preview->getWidget());
-#else
 	preview->previewBlock(-1, -1);
-#endif
 	field->hidePauseMessage();
 	field->showGameOverMessage();
 	games_sound_play ("gameover");
@@ -1289,10 +1210,6 @@ Tetris::endOfGame()
 		int pos = high_scores->add (scoreFrame->getScore());
 		high_scores->show (GTK_WINDOW (w), pos);
 	}
-
-#ifndef HAVE_CLUTTER
-	field->setUseTarget (false);
-#endif
 }
 
 int
@@ -1320,10 +1237,6 @@ Tetris::gameNew(GtkAction *action, void *d)
 	t->scoreFrame->setLevel(level);
 	t->scoreFrame->setStartingLevel(level);
 
-#ifndef HAVE_CLUTTER
-	t->field->setUseTarget (t->useTarget);
-#endif
-
 	t->generateTimer (level);
 	t->field->emptyField(t->line_fill_height,t->line_fill_prob);
 
@@ -1331,15 +1244,8 @@ Tetris::gameNew(GtkAction *action, void *d)
 	t->paused = false;
 
 	t->field->generateFallingBlock();
-#ifndef HAVE_CLUTTER
-	t->field->redraw();
-
-	t->preview->previewBlock(blocknr_next, rot_next, color_next);
-	gtk_widget_queue_draw(t->preview->getWidget());
-#else
 	t->field->putBlockInField(FALLING);
 	t->preview->previewBlock(blocknr_next, color_next);
-#endif
 
 	gtk_action_set_visible(t->pause_action, TRUE);
 	gtk_action_set_visible(t->resume_action, FALSE);
@@ -1382,7 +1288,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 #endif
 			       "version", VERSION,
 			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
-			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2008 Others",
+			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2009 Others",
 			       "license", license,
 			       "website-label", _("GNOME Games web site"),
 			       "authors", authors,
