@@ -34,19 +34,12 @@ _games_debug_init (void)
     { "card-theme",   GAMES_DEBUG_CARD_THEME   },
     { "card-cache",   GAMES_DEBUG_CARD_CACHE   },
     { "runtime",      GAMES_DEBUG_RUNTIME      },
-    { "sound ",       GAMES_DEBUG_SOUND        },
+    { "sound",        GAMES_DEBUG_SOUND        },
     { "window-state", GAMES_DEBUG_WINDOW_STATE }
   };
-  const char *env;
 
-  env = g_getenv ("GAMES_DEBUG");
-
-#if !GLIB_CHECK_VERSION (2, 16, 0)
-  /* g_parse_debug_string is only NULL-safe since 2.16 */
-  if (env == NULL)
-    return;
-#endif
-
-  _games_debug_flags = g_parse_debug_string (env, keys, G_N_ELEMENTS (keys));
+  _games_debug_flags = g_parse_debug_string (g_getenv ("GAMES_DEBUG"),
+                                             keys, G_N_ELEMENTS (keys));
 #endif /* GNOME_ENABLE_DEBUG */
 }
+
